"""
errors and exceptions
"""

from distutils.version import LooseVersion
from pkg_resources import get_distribution
from werkzeug import exceptions
from six import text_type


werkzeug_version = get_distribution("werkzeug").version
if LooseVersion(werkzeug_version) < LooseVersion("0.9"):  # pragma: no cover
    # sorry, for touching your internals :).
    import werkzeug._internal
    werkzeug._internal.HTTP_STATUS_CODES[429] = 'Too Many Requests'

    class RateLimitExceeded(exceptions.HTTPException):
        """
        exception raised when a rate limit is hit.
        The exception results in ``abort(429)`` being called.
        """
        code = 429

        def __init__(self, limit):
            self.description = text_type(limit)
            super(RateLimitExceeded, self).__init__()
else:
    # Werkzeug 0.9 and up have an existing exception for 429
    RateLimitExceeded = exceptions.TooManyRequests



"""
setup.py for Flask-Limiter


"""
__author__ = "Ali-Akber Saifee"
__email__ = "ali@indydevs.org"
__copyright__ = "Copyright 2014, Ali-Akber Saifee"

from setuptools import setup, find_packages
import os

this_dir = os.path.abspath(os.path.dirname(__file__))
REQUIREMENTS = filter(None, open(
    os.path.join(this_dir, 'requirements', 'main.txt')).read().splitlines())

import versioneer

setup(
    name='Flask-Limiter',
    author=__author__,
    author_email=__email__,
    license="MIT",
    url="https://flask-limiter.readthedocs.org",
    zip_safe=False,
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    install_requires=list(REQUIREMENTS),
    classifiers=[k for k in open('CLASSIFIERS').read().split('\n') if k],
    description='Rate limiting for flask applications',
    long_description=open('README.rst').read() + open('HISTORY.rst').read(),
    packages=find_packages(exclude=["tests*"]),
)

